==> kubernetes-model-core-4.12.0-sources.jar: io/fabric8/kubernetes/api/model/NodeDaemonEndpointsBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class NodeDaemonEndpointsBuilder extends NodeDaemonEndpointsFluentImpl<NodeDaemonEndpointsBuilder> implements VisitableBuilder<NodeDaemonEndpoints,NodeDaemonEndpointsBuilder> {

    NodeDaemonEndpointsFluent<?> fluent;
    Boolean validationEnabled;

    public NodeDaemonEndpointsBuilder() { 
        this(true);
    }


    public NodeDaemonEndpointsBuilder(Boolean validationEnabled) { 
        this(new NodeDaemonEndpoints(), validationEnabled);
    }


    public NodeDaemonEndpointsBuilder(NodeDaemonEndpointsFluent<?> fluent) { 
        this(fluent, true);
    }


    public NodeDaemonEndpointsBuilder(NodeDaemonEndpointsFluent<?> fluent,Boolean validationEnabled) { 
        this(fluent, new NodeDaemonEndpoints(), validationEnabled);
    }


    public NodeDaemonEndpointsBuilder(NodeDaemonEndpointsFluent<?> fluent,NodeDaemonEndpoints instance) { 
        this(fluent, instance, true);
    }


    public NodeDaemonEndpointsBuilder(NodeDaemonEndpointsFluent<?> fluent,NodeDaemonEndpoints instance,Boolean validationEnabled) { 
        this.fluent = fluent; 
        fluent.withKubeletEndpoint(instance.getKubeletEndpoint()); 
        this.validationEnabled = validationEnabled; 
    }


    public NodeDaemonEndpointsBuilder(NodeDaemonEndpoints instance) { 
        this(instance,true);
    }


    public NodeDaemonEndpointsBuilder(NodeDaemonEndpoints instance,Boolean validationEnabled) { 
        this.fluent = this; 
        this.withKubeletEndpoint(instance.getKubeletEndpoint()); 
        this.validationEnabled = validationEnabled; 
    }


    public NodeDaemonEndpoints build() {
        NodeDaemonEndpoints buildable = new NodeDaemonEndpoints(fluent.getKubeletEndpoint());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        NodeDaemonEndpointsBuilder that = (NodeDaemonEndpointsBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}

==> kubernetes-model-core-5.3.2-sources.jar: io/fabric8/kubernetes/api/model/NodeDaemonEndpointsBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class NodeDaemonEndpointsBuilder extends NodeDaemonEndpointsFluentImpl<NodeDaemonEndpointsBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<NodeDaemonEndpoints,NodeDaemonEndpointsBuilder> {

    NodeDaemonEndpointsFluent<?> fluent;
    Boolean validationEnabled;

    public NodeDaemonEndpointsBuilder() {
        this(true);
    }

    public NodeDaemonEndpointsBuilder(Boolean validationEnabled) {
        this(new NodeDaemonEndpoints(), validationEnabled);
    }

    public NodeDaemonEndpointsBuilder(NodeDaemonEndpointsFluent<?> fluent) {
        this(fluent, true);
    }

    public NodeDaemonEndpointsBuilder(NodeDaemonEndpointsFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new NodeDaemonEndpoints(), validationEnabled);
    }

    public NodeDaemonEndpointsBuilder(NodeDaemonEndpointsFluent<?> fluent,NodeDaemonEndpoints instance) {
        this(fluent, instance, true);
    }

    public NodeDaemonEndpointsBuilder(NodeDaemonEndpointsFluent<?> fluent,NodeDaemonEndpoints instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withKubeletEndpoint(instance.getKubeletEndpoint()); 
        this.validationEnabled = validationEnabled; 
    }

    public NodeDaemonEndpointsBuilder(NodeDaemonEndpoints instance) {
        this(instance,true);
    }

    public NodeDaemonEndpointsBuilder(NodeDaemonEndpoints instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withKubeletEndpoint(instance.getKubeletEndpoint()); 
        this.validationEnabled = validationEnabled; 
    }

    public NodeDaemonEndpoints build() {
        NodeDaemonEndpoints buildable = new NodeDaemonEndpoints(fluent.getKubeletEndpoint());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        NodeDaemonEndpointsBuilder that = (NodeDaemonEndpointsBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}
